/*
 * text.c
 *
 * Copyright 2022 Jonathan Schöbel <jonathan@Ubermos-2019>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 */


#include <stdlib.h>

#include "error.h"
#include "log.h"

#include "text.h"


struct SH_Text *
SH_Text_new (struct SH_Error * error)
{
	struct SH_Text * text;
	text = malloc (sizeof (struct SH_Text));

	if (text == NULL)
	{
		ERROR1 ("Memory allocation for SH_Text failed.\n");

		if (error != NULL)
		{
			error->type = ALLOCATION_FAILED;
		}

		return NULL;
	}

	text->length = 0;
	text->size = 1;
	text->text = malloc (1);
	text->text[0] = 0;

	if (error != NULL)
	{
		error->type = SUCCESS;
	}

	return text;
}

void
SH_Text_free (struct SH_Text * text, struct SH_Error * error)
{
	free (text->text);

	free (text);

	if (error != NULL)
	{
		error->type = SUCCESS;
	}

	return;
}
